#include "config.h"
#include "tft_gfx.h"
#include "tft_master.h"
#include <stdio.h>
#define	SYS_FREQ 40000000 
#include "nrf24l01.h"
// These two defines are for the tft
#define spi_channel	1
#define spi_divider 10

/* This code sends four arrays of different sizes using the 
 * dynamic payload length (dpl) feature of the radio. This file is the
 * receiver and will receive arrays of varying size and display them. The other
 * file will create and send these arrays.
 */

// set up the radio
void radioSetup() {
    nrf_setup(); // initializing function  
    nrf_set_rf_ch(0x64); // freq = 2.410 GHz  2400+ch(MHz)

	nrf_en_aa(0);        // enable autoack on pipe0
	nrf_set_pw(1,0);     // set the payload width to be 1 byte (1-32 bytes, 0-5 pipe)

	nrf_set_address_width(3);   // set the address width 5 bytes(3-5)

	// tx address and the pipe 0 rx address must be the same for autoack mode
	nrf_set_rx_addr(0, 0xAABBCC, 3);  // set pipe 0, receiver address to be 5 bytes

}
void main(void) {
    INTEnableSystemMultiVectoredInt();
    radioSetup(); // setup the radio for this program   
    OpenTimer3(T3_ON | T3_PS_1_1, 40000);
    mINT1ClearIntFlag();
    
    // light level: 0-off(ct=0); 2-dim(ct=1500); 3-mid(ct=3000); 4-on(ct=40001))
    // OpenOC1(OC_ON | OC_TIMER3_SRC | OC_PWM_FAULT_PIN_DISABLE , light_level, 20000 ); //
    // OC1 is PPS group 4, map to RPA0 (pin 2)
    PPSOutput(1, RPA0, OC1);
    
    tft_init_hw(); // setup for tft
    tft_begin(); // setup for tft
    tft_fillScreen(ILI9340_BLACK);
    //240x320 vertical display
    tft_setRotation(0); // Use tft_setRotation(1) for 320x240
    char buffer[120]; // a buffer for writing to the tft
    // arrays to read payloads into
    char rx_message;
    int width=1; // the width of the received payload
    tft_setTextColor(ILI9340_GREEN);
    tft_setTextSize(2);
    tft_setCursor(0, 0);
    sprintf(buffer, "%s", "Waiting for data...");
    tft_writeString(buffer);
    
    int led_level=0;
    int i=0;  // # of the received messages for TFT
    while (1) {
    
        // enter receive mode to search for packets
        nrf_state_rx_mode();
        if(nrf_payload_available()){ // wait for a payload to be received
            
            //nrf_delay_ms(10);
            
            nrf_get_payload(&rx_message, 1); // read the payload into the array
          
            if(rx_message == 0){

                OpenOC1(OC_ON | OC_TIMER3_SRC | OC_PWM_FAULT_PIN_DISABLE , 0, 20000 );
                led_level = 0;
            }
            else if(rx_message == 3){

                OpenOC1(OC_ON | OC_TIMER3_SRC | OC_PWM_FAULT_PIN_DISABLE , 40001, 20000 );
                led_level = 40001;
            }
            
          if( (led_level>0) & (led_level<=40001) ){
              
            if(rx_message == 1){

                led_level = led_level + 8000;
                if(led_level>40001)
                {
                    led_level = 40000;
                }
                OpenOC1(OC_ON | OC_TIMER3_SRC | OC_PWM_FAULT_PIN_DISABLE , led_level, 20000 );
            }
            
            else if(rx_message == 2){
                
                led_level = led_level - 8000;
                if(led_level<8000)
                {
                    led_level = 8000;
                }
                OpenOC1(OC_ON | OC_TIMER3_SRC | OC_PWM_FAULT_PIN_DISABLE , led_level, 20000 );
            }
          }
            
            // display the received data on the tft
            tft_setTextColor(ILI9340_BLUE);
            tft_setTextSize(2);
            tft_setCursor(0, 20);
            sprintf(buffer, "%s", "Received data:");
            tft_writeString(buffer);
            
            tft_setCursor(40, 60);
            tft_setTextColor(ILI9340_RED);
            sprintf(buffer, "%s", "Width:");
            tft_writeString(buffer);
            
            tft_setCursor(110, 60);
            sprintf(buffer, "%d", width);
            tft_writeString(buffer);
            
            tft_setTextColor(ILI9340_BLUE);                      
            tft_setCursor(0, 40+20*i);
            sprintf(buffer,"%d", rx_message);
            tft_writeString(buffer);
            i=i+1;
            nrf_delay_ms(500);
        }
    }
} // main

// === end  ======================================================
